Siebrand has uploaded a new change for review.
https://gerrit.wikimedia.org/r/51994
Change subject: Use American English spelling for behavior
......................................................................
Use American English spelling for behavior
Spotted in ipbreason-dropdown by Shirayuki.
Change-Id: I576ed4bc0abe5ab980aaee3fb9f9e4b43087311f
---
M HISTORY
M UPGRADE
M docs/hooks.txt
M includes/Action.php
M includes/DefaultSettings.php
M includes/EditPage.php
M includes/Linker.php
M includes/Revision.php
M includes/SkinLegacy.php
M includes/SpecialPage.php
M includes/StringUtils.php
M includes/Title.php
M includes/WatchedItem.php
M includes/ZipDirectoryReader.php
M includes/api/ApiParse.php
M includes/api/ApiWatch.php
M includes/content/Content.php
M includes/content/ContentHandler.php
M includes/filerepo/README
M includes/filerepo/file/ForeignDBFile.php
M includes/libs/GenericArrayObject.php
M includes/libs/IEUrlExtension.php
M includes/objectcache/SqlBagOStuff.php
M includes/parser/Parser.php
M includes/parser/Preprocessor_DOM.php
M includes/parser/Preprocessor_Hash.php
M includes/site/MediaWikiSite.php
M includes/specials/SpecialFilepath.php
M includes/specials/SpecialSearch.php
M languages/messages/MessagesEn.php
M languages/messages/MessagesGv.php
M languages/messages/MessagesQqq.php
M maintenance/language/messages.inc
M maintenance/storage/recompressTracked.php
M resources/mediawiki/mediawiki.util.js
M skins/common/commonElements.css
M tests/RunSeleniumTests.php
M tests/parser/parserTests.txt
M tests/phpunit/maintenance/MaintenanceTest.php
M tests/qunit/suites/resources/jquery/jquery.colorUtil.test.js
M tests/qunit/suites/resources/jquery/jquery.mwExtension.test.js
41 files changed, 70 insertions(+), 70 deletions(-)
git pull ssh://gerrit.wikimedia.org:29418/mediawiki/core
refs/changes/94/51994/1
diff --git a/HISTORY b/HISTORY
index 3a25b97..311a52a 100644
--- a/HISTORY
+++ b/HISTORY
@@ -132,7 +132,7 @@
* (bug 39273) Added AJAX support for "Show changes" (diff) in LivePreview.
* Added ResourceLoader module "jquery.badge".
* mw.util.$content now points to the overall content area in the skin rather
than just
- page text content area. If you need the old behaviour please use $(
'#mw-content-text').
+ page text content area. If you need the old behavior please use $(
'#mw-content-text').
* jsMessage has been replaced with a floating bubble notification system
complete
with auto-hide, multi-message support, and message replacement tags.
* jquery.messageBox which appears to be unused by both core and extensions has
@@ -1135,7 +1135,7 @@
* New maintenance script to refresh image metadata
(maintenance/refreshImageMetadata.php).
* (bug 16428) Include permalink in printable version.
* (bug 30722) Add an identity collation that sorts things based on what the
- unicode code point is (aka pre-1.17 behaviour).
+ unicode code point is (aka pre-1.17 behavior).
* (bug 30940) Add a hook in User:getDefaultOptions.
To give extensions a better and more flexible way of providing default
values for preferences a hook has been introdiced in
User:getDefaultOptions().
@@ -2125,7 +2125,7 @@
make wfTempDir() return a sane value for Windows on worst-case.
* (bug 24824) Support ImageMagick 6.5.6-2+ JPEG decoder size hint, to reduce
memory usage when such an ImageMagick is used for scaling.
-* Disable multithreaded behaviour in recent ImageMagick, to avoid a deadlock
+* Disable multithreaded behavior in recent ImageMagick, to avoid a deadlock
when a resource limit such as $wgMaxShellMemory is hit.
* (bug 24981) Allow extensions to access SpecialUpload variables again.
* (bug 20744) Wiki forgets about an uploaded file.
@@ -2518,8 +2518,8 @@
exist. In that case the URL will get (?|&)wpDestFile=<filename> appended to
it as appropriate.
* If $wgLocaltimezone is null, use the server's timezone as the default for
- signatures. This was always the behaviour documented in DefaultSettings.php
- but has not been the actual behaviour for some time: instead, UTC was used
+ signatures. This was always the behavior documented in DefaultSettings.php
+ but has not been the actual behavior for some time: instead, UTC was used
by default.
* Added $wgExtensionAssetsPath, to decouple assets serving from $wgScriptPath.
If not specified it will default to $wgScriptPath/extensions
@@ -4716,7 +4716,7 @@
* (bug 12644) Template list on edit page now sorted on preview
* (bug 14058) Support pipe trick for namespaces and interwikis with "-"
* Message name filter on Special:Allmessages now case-insensitive
-* (bug 13943) Fix image redirect behaviour on image pages
+* (bug 13943) Fix image redirect behavior on image pages
* (bug 14093) Do 'sysop' => 'protect' magic in Title::isValidMoveOperation
* (bug 14063) Power search form missing <label> for redirects check
* (bug 14111) Similar filename warning links now lead to correct page
@@ -4939,7 +4939,7 @@
to not check and assume they are always up to date)
* The rollback permission can now be rate-limited using the normal mechanism.
* New configuration variable $wgExtraLanguageNames
-* Behaviour of $wgAddGroups and $wgRemoveGroups changed. New behaviour:
+* Behaviour of $wgAddGroups and $wgRemoveGroups changed. New behavior:
* * Granting the userrights privilege allows arbitrary changing of rights.
* * Without the userrights privilege, a user will be able to add and/or
remove the groups specified in $wgAddGroups and $wgRemoveGroups for
@@ -5351,7 +5351,7 @@
Message transformation mode has been removed, and replaced with "preprocess"
mode. This means that some MediaWiki namespace messages may need to be updated,
-especially ones which took advantage of the terribly counterintuitive behaviour
+especially ones which took advantage of the terribly counterintuitive behavior
of the former message mode.
The header identification routines for section edit and for numbering section
@@ -5361,7 +5361,7 @@
entry in the TOC, but will not have a section edit link. HTML-style headings
will also not have a section edit link. Valid wikitext headings present in the
template source text will get a template section edit link. This is a major
-break from previous behaviour, but I believe the effects are almost entirely
+break from previous behavior, but I believe the effects are almost entirely
beneficial.
The main motivation for making these changes was performance. The new two-pass
@@ -5568,7 +5568,7 @@
enabled by default.
* Added option to install to MyISAM
* (bug 9250) Remove hardcoded minimum image name length of three characters
-* Fixed DISPLAYTITLE behaviour to reject titles which don't normalise to the
+* Fixed DISPLAYTITLE behavior to reject titles which don't normalise to the
same title as the current page, and enabled per default
* Wrap site CSS and JavaScript in a <pre> tag, like user JS/CSS
* (bug 10196) Add classes and dir="ltr" to the <pre>s on CSS and JS pages (new
@@ -5850,7 +5850,7 @@
* Fix upload form display in right-to-left languages
* Fixed regression in blocking of username '0'
* (bug 9437) Don't overwrite edit form submission handler when setting up
- edit box scroll position preserve/restore behaviour
+ edit box scroll position preserve/restore behavior
* (bug 10805) Fix "undo" link when viewing the diff of the most recent
change to a page using "diff=0"
* (bug 10765) img_auth.php will now refuse logged-out requests where
@@ -6396,7 +6396,7 @@
to image/svg+xml after loading from the database.
* Workaround for djvutoxml bug #1704049 (poor performance). Use djvudump
instead.
-* Fixed odd behaviour in ImagePage on DjVu thumbnailing errors
+* Fixed odd behavior in ImagePage on DjVu thumbnailing errors
* (bug 5439) "Go" title search will now jump to shared/foreign Image: and
MediaWiki: pages that have not been locally edited.
* (bug 9630) Limits links in Whatlinkshere forgot about namespace filter
@@ -7002,7 +7002,7 @@
* New maintenance script to show the cached statistics : showStats.php.
* Count deleted edits when regenerating total edits in
maintenance/initStats.php
* (bug 3706) Allow users to be exempted from IP blocks. The ipblock-exempt
permission
- key has been added to enable this behaviour, by default assigned to sysops.
+ key has been added to enable this behavior, by default assigned to sysops.
* (bug 7948) importDump.php now warn that Recentchanges need to be rebuild.
* (bug 7667) allow XHTML namespaces customization
* (bug 8531) Correct local name of Lingála (patch by Raymond)
@@ -7281,7 +7281,7 @@
* (bug 6642) Don't offer to unlock the database when it isn't locked
* cleanupTitles.php changed from --dry-run option to --fix, so default
behavior is now a non-invasive check as with namespaceDupes.php
-* (bug 6660) Fix behaviour of EditPage::blockedPage() when the article does
+* (bug 6660) Fix behavior of EditPage::blockedPage() when the article does
not exist; now doesn't show the source box if the user hasn't provided it
(blocked mid-edit) and the page doesn't exist
* Improve default value of "blockedtext"
@@ -7442,7 +7442,7 @@
* (bug 6023) Fixed mismatch of 0/NULL for wl_notificationtimestamp; now
notification
mails are working after 'Mark all pages visited' button on Special:Watchlist
is clicked
* Made {{INT:}} a core parser function instead of a special case. The syntax
- and behaviour is largely unchanged.
+ and behavior is largely unchanged.
* (bug 7448) Fixing the native name for Ewe (ee)
* (bug 6864) Replace message 'editing' with new message 'editinguser' in
Special:Userrights
to allow better localisation
@@ -10320,7 +10320,7 @@
* (bug 1283) Use underlining and borders to highlight additions/deletions
in diff-view
* Use user's local timezone in Special:Log display
-* Show filename for images in gallery by default (restore beta 3 behaviour)
+* Show filename for images in gallery by default (restore beta 3 behavior)
* (bug 1201) Double-escaping in brokenlinks, imagelinks, categorylinks,
searchindex
* When using squid reverse proxy, cache the redirect to the Main_Page
* (bug 1302) Fix Norwegian language file
diff --git a/UPGRADE b/UPGRADE
index 2c6df98..7987b22 100644
--- a/UPGRADE
+++ b/UPGRADE
@@ -81,7 +81,7 @@
can change between release branches, e.g. $wgDisableUploads in 1.4 is replaced
with $wgEnableUploads in later versions. When upgrading, consult the release
notes to check for configuration changes which would alter the expected
-behaviour of MediaWiki.
+behavior of MediaWiki.
=== Check installed extensions ===
diff --git a/docs/hooks.txt b/docs/hooks.txt
index 28eedf4..25a193b 100644
--- a/docs/hooks.txt
+++ b/docs/hooks.txt
@@ -2285,7 +2285,7 @@
Title::isCssOrJsPage().
'TitleIsAlwaysKnown': Called when determining if a page exists. Allows
-overriding default behaviour for determining if a page exists. If $isKnown is
+overriding default behavior for determining if a page exists. If $isKnown is
kept as null, regular checks happen. If it's a boolean, this value is returned
by the isKnown method.
$title: Title object that is being checked
diff --git a/includes/Action.php b/includes/Action.php
index 40ce478..cace4b4 100644
--- a/includes/Action.php
+++ b/includes/Action.php
@@ -388,7 +388,7 @@
protected function alterForm( HTMLForm $form ) {}
/**
- * Get the HTMLForm to control behaviour
+ * Get the HTMLForm to control behavior
* @return HTMLForm|null
*/
protected function getForm() {
@@ -439,7 +439,7 @@
* some stuff underneath (history etc); to do some processing on
submission of that
* form (delete, protect, etc) and to do something exciting on
'success', be that
* display something new or redirect to somewhere. Some actions have
more exotic
- * behaviour, but that's what subclassing is for :D
+ * behavior, but that's what subclassing is for :D
*/
public function show() {
$this->setHeaders();
diff --git a/includes/DefaultSettings.php b/includes/DefaultSettings.php
index 73c097e..97e9d1b 100644
--- a/includes/DefaultSettings.php
+++ b/includes/DefaultSettings.php
@@ -1837,7 +1837,7 @@
/**
* Store sessions in an object cache, configured by $wgSessionCacheType. This
- * can be useful to improve performance, or to avoid the locking behaviour of
+ * can be useful to improve performance, or to avoid the locking behavior of
* PHP's default session handler, which tends to prevent multiple requests for
* the same user from acting concurrently.
*/
@@ -2207,7 +2207,7 @@
* change it in their preferences.
*
* This also defines the language of pages in the wiki. The content is wrapped
- * in a html element with lang=XX attribute. This behaviour can be overriden
+ * in a html element with lang=XX attribute. This behavior can be overriden
* via hooks, see Title::getPageLanguage.
*/
$wgLanguageCode = 'en';
@@ -4971,7 +4971,7 @@
/**
* Path to the GNU diff3 utility. If the file doesn't exist, edit conflicts
will
- * fall back to the old behaviour (no merging).
+ * fall back to the old behavior (no merging).
*/
$wgDiff3 = '/usr/bin/diff3';
diff --git a/includes/EditPage.php b/includes/EditPage.php
index d42edd7..027fa01 100644
--- a/includes/EditPage.php
+++ b/includes/EditPage.php
@@ -563,7 +563,7 @@
// Nothing *to* preview for new sections
return false;
} elseif ( ( $wgRequest->getVal( 'preload' ) !== null ||
$this->mTitle->exists() ) && $wgUser->getOption( 'previewonfirst' ) ) {
- // Standard preference behaviour
+ // Standard preference behavior
return true;
} elseif ( !$this->mTitle->exists() &&
isset(
$wgPreviewOnOpenNamespaces[$this->mTitle->getNamespace()] ) &&
diff --git a/includes/Linker.php b/includes/Linker.php
index a96bc5f..2434a70 100644
--- a/includes/Linker.php
+++ b/includes/Linker.php
@@ -660,7 +660,7 @@
if ( $file && isset( $fp['frameless'] ) ) {
$srcWidth = $file->getWidth( $page );
# For "frameless" option: do not present an image
bigger than the source (for bitmap-style images)
- # This is the same behaviour as the "thumb" option does
it already.
+ # This is the same behavior as the "thumb" option does
it already.
if ( $srcWidth && !$file->mustRender() && $hp['width']
> $srcWidth ) {
$hp['width'] = $srcWidth;
}
@@ -819,7 +819,7 @@
$noscale = true;
} else {
# Do not present an image bigger than the
source, for bitmap-style images
- # This is a hack to maintain compatibility with
arbitrary pre-1.10 behaviour
+ # This is a hack to maintain compatibility with
arbitrary pre-1.10 behavior
$srcWidth = $file->getWidth( $page );
if ( $srcWidth && !$file->mustRender() &&
$hp['width'] > $srcWidth ) {
$hp['width'] = $srcWidth;
diff --git a/includes/Revision.php b/includes/Revision.php
index df1e43e..0cb2c79 100644
--- a/includes/Revision.php
+++ b/includes/Revision.php
@@ -1327,7 +1327,7 @@
if ( $wgContentHandlerUseDB ) {
//NOTE: Store null for the default model and format, to
save space.
- //XXX: Makes the DB sensitive to changed defaults. Make
this behaviour optional? Only in miser mode?
+ //XXX: Makes the DB sensitive to changed defaults. Make
this behavior optional? Only in miser mode?
$model = $this->getContentModel();
$format = $this->getContentFormat();
diff --git a/includes/SkinLegacy.php b/includes/SkinLegacy.php
index c1c7219..b9766a9 100644
--- a/includes/SkinLegacy.php
+++ b/includes/SkinLegacy.php
@@ -786,7 +786,7 @@
return '';
}
- # __NEWSECTIONLINK___ changes behaviour here
+ # __NEWSECTIONLINK___ changes behavior here
# If it is present, the link points to this page, otherwise
# it points to the talk page
if ( !$title->isTalkPage() && !$wgOut->showNewSectionLink() ) {
diff --git a/includes/SpecialPage.php b/includes/SpecialPage.php
index 3b3a5ee..5801e2a 100644
--- a/includes/SpecialPage.php
+++ b/includes/SpecialPage.php
@@ -302,7 +302,7 @@
* be displayed by the default execute() method, without the global
function ever
* being called.
*
- * If you override execute(), you can recover the default behaviour
with userCanExecute()
+ * If you override execute(), you can recover the default behavior
with userCanExecute()
* and displayRestrictionError()
*
* @param $name String: name of the special page, as seen in links and
URLs
@@ -695,7 +695,7 @@
* also the name that will be listed in Special:Specialpages
*
* Derived classes can override this, but usually it is easier to keep
the
- * default behaviour. Messages can be added at run-time, see
+ * default behavior. Messages can be added at run-time, see
* MessageCache.php.
*
* @return String
@@ -889,7 +889,7 @@
}
/**
- * Get the HTMLForm to control behaviour
+ * Get the HTMLForm to control behavior
* @return HTMLForm|null
*/
protected function getForm() {
diff --git a/includes/StringUtils.php b/includes/StringUtils.php
index 6647de41..9543d1f 100644
--- a/includes/StringUtils.php
+++ b/includes/StringUtils.php
@@ -110,7 +110,7 @@
* memory. The delimiters are literal strings, not regular expressions.
*
* If the start delimiter ends with an initial substring of the end
delimiter,
- * e.g. in the case of C-style comments, the behaviour differs from the
model
+ * e.g. in the case of C-style comments, the behavior differs from the
model
* regex. In this implementation, the end must share no characters with
the
* start, so e.g. /*\/ is not considered to be both the start and end
of a
* comment. /*\/xy/*\/ is considered to be a single comment with
contents /xy/.
diff --git a/includes/Title.php b/includes/Title.php
index b0a6a00..86d1552 100644
--- a/includes/Title.php
+++ b/includes/Title.php
@@ -4397,7 +4397,7 @@
$isKnown = null;
/**
- * Allows overriding default behaviour for determining if a
page exists.
+ * Allows overriding default behavior for determining if a page
exists.
* If $isKnown is kept as null, regular checks happen. If it's
* a boolean, this value is returned by the isKnown method.
*
diff --git a/includes/WatchedItem.php b/includes/WatchedItem.php
index 240ebc7..5ac92f7 100644
--- a/includes/WatchedItem.php
+++ b/includes/WatchedItem.php
@@ -205,7 +205,7 @@
$success = true;
}
- # the following code compensates the new behaviour, introduced
by the
+ # the following code compensates the new behavior, introduced
by the
# enotif patch, that every single watched page needs now to be
listed
# in watchlist namespace:page and namespace_talk:page had
separate
# entries: clear them
diff --git a/includes/ZipDirectoryReader.php b/includes/ZipDirectoryReader.php
index fc36b1f..e5423f5 100644
--- a/includes/ZipDirectoryReader.php
+++ b/includes/ZipDirectoryReader.php
@@ -34,7 +34,7 @@
*
* Because this class is aimed at verification, an error is raised on
* suspicious or ambiguous input, instead of emulating some standard
- * behaviour.
+ * behavior.
*
* @param $fileName string The archive file name
* @param $callback Array The callback function. It will be called for
each file
diff --git a/includes/api/ApiParse.php b/includes/api/ApiParse.php
index ec8bfee..09b7a88 100644
--- a/includes/api/ApiParse.php
+++ b/includes/api/ApiParse.php
@@ -68,7 +68,7 @@
// TODO: Does this still need $wgTitle?
global $wgParser, $wgTitle;
- // Currently unnecessary, code to act as a safeguard against
any change in current behaviour of uselang
+ // Currently unnecessary, code to act as a safeguard against
any change in current behavior of uselang
$oldLang = null;
if ( isset( $params['uselang'] ) && $params['uselang'] !=
$this->getContext()->getLanguage()->getCode() ) {
$oldLang = $this->getContext()->getLanguage(); //
Backup language
diff --git a/includes/api/ApiWatch.php b/includes/api/ApiWatch.php
index 7106b06..3e51299 100644
--- a/includes/api/ApiWatch.php
+++ b/includes/api/ApiWatch.php
@@ -46,7 +46,7 @@
$res = array( 'title' => $title->getPrefixedText() );
- // Currently unnecessary, code to act as a safeguard against
any change in current behaviour of uselang
+ // Currently unnecessary, code to act as a safeguard against
any change in current behavior of uselang
// Copy from ApiParse
$oldLang = null;
if ( isset( $params['uselang'] ) && $params['uselang'] !=
$this->getContext()->getLanguage()->getCode() ) {
diff --git a/includes/content/Content.php b/includes/content/Content.php
index 31345af..9ebd98e 100644
--- a/includes/content/Content.php
+++ b/includes/content/Content.php
@@ -335,7 +335,7 @@
* target is hit in order to provide (hopefully) the Title of the final
* destination instead of another redirect.
*
- * There is usually no need to override the default behaviour,
subclasses that
+ * There is usually no need to override the default behavior,
subclasses that
* want to implement redirects should override getRedirectTarget().
*
* @since 1.21
diff --git a/includes/content/ContentHandler.php
b/includes/content/ContentHandler.php
index 5e0447f..d87c72d 100644
--- a/includes/content/ContentHandler.php
+++ b/includes/content/ContentHandler.php
@@ -83,7 +83,7 @@
* form of the content.
* - If $wgContentHandlerTextFallback is 'ignore' and $content is not a
* TextContent object, this method returns null.
- * - otherwise, the behaviour is undefined.
+ * - otherwise, the behavior is undefined.
*
* @since 1.21
*
diff --git a/includes/filerepo/README b/includes/filerepo/README
index d3aea9f..1423d35 100644
--- a/includes/filerepo/README
+++ b/includes/filerepo/README
@@ -18,10 +18,10 @@
FileRepo, where no such configuration is needed.
File objects are generated by a factory function from the repository. The
-repository thus has full control over the behaviour of its subsidiary file
+repository thus has full control over the behavior of its subsidiary file
class, since it can subclass the file class and override functionality at its
whim. Thus there is no need for the File subclass to query its parent
repository
-for information about repository-class-dependent behaviour -- the file subclass
+for information about repository-class-dependent behavior -- the file subclass
is generally fully aware of the static preferences of its repository. Limited
exceptions can be made to this rule to permit sharing of functions, or perhaps
even entire classes, between repositories.
diff --git a/includes/filerepo/file/ForeignDBFile.php
b/includes/filerepo/file/ForeignDBFile.php
index 610f556..ee5883c 100644
--- a/includes/filerepo/file/ForeignDBFile.php
+++ b/includes/filerepo/file/ForeignDBFile.php
@@ -115,7 +115,7 @@
* @return string
*/
function getDescriptionUrl() {
- // Restore remote behaviour
+ // Restore remote behavior
return File::getDescriptionUrl();
}
@@ -123,7 +123,7 @@
* @return string
*/
function getDescriptionText() {
- // Restore remote behaviour
+ // Restore remote behavior
return File::getDescriptionText();
}
}
diff --git a/includes/libs/GenericArrayObject.php
b/includes/libs/GenericArrayObject.php
index ef7587d..d77d8ad 100644
--- a/includes/libs/GenericArrayObject.php
+++ b/includes/libs/GenericArrayObject.php
@@ -191,7 +191,7 @@
/**
* Returns an array holding all the data that should go into
serialization calls.
* This is intended to allow overloading without having to reimplement
the
- * behaviour of this base class.
+ * behavior of this base class.
*
* @since 1.20
*
diff --git a/includes/libs/IEUrlExtension.php b/includes/libs/IEUrlExtension.php
index e9cfa99..065fc3c 100644
--- a/includes/libs/IEUrlExtension.php
+++ b/includes/libs/IEUrlExtension.php
@@ -245,7 +245,7 @@
* whether the script filename has been obscured.
*
* The function returns false if the server is not known to have this
- * behaviour. Microsoft IIS in particular is known to decode escaped
script
+ * behavior. Microsoft IIS in particular is known to decode escaped
script
* filenames.
*
* SERVER_SOFTWARE typically contains either a plain string such as
"Zeus",
diff --git a/includes/objectcache/SqlBagOStuff.php
b/includes/objectcache/SqlBagOStuff.php
index 2404703..87f787d 100644
--- a/includes/objectcache/SqlBagOStuff.php
+++ b/includes/objectcache/SqlBagOStuff.php
@@ -133,7 +133,7 @@
} else {
/*
* We must keep a separate connection to MySQL
in order to avoid deadlocks
- * However, SQLite has an opposite behaviour.
And PostgreSQL needs to know
+ * However, SQLite has an opposite behavior.
And PostgreSQL needs to know
* if we are in transaction or no
*/
if ( wfGetDB( DB_MASTER )->getType() == 'mysql'
) {
diff --git a/includes/parser/Parser.php b/includes/parser/Parser.php
index ed5071e..e10fa57 100644
--- a/includes/parser/Parser.php
+++ b/includes/parser/Parser.php
@@ -305,7 +305,7 @@
* string constructs.
*
* Must not consist of all title characters, or else it will
change
- * the behaviour of <nowiki> in a link.
+ * the behavior of <nowiki> in a link.
*/
$this->mUniqPrefix = "\x7fUNIQ" . self::getRandomString();
$this->mStripState = new StripState( $this->mUniqPrefix );
@@ -3471,7 +3471,7 @@
{
# Bug 529: if the template begins with a table or
block-level
# element, it should be treated as beginning a new line.
- # This behaviour is somewhat controversial.
+ # This behavior is somewhat controversial.
$text = "\n" . $text;
}
diff --git a/includes/parser/Preprocessor_DOM.php
b/includes/parser/Preprocessor_DOM.php
index 468802d..9c7eef5 100644
--- a/includes/parser/Preprocessor_DOM.php
+++ b/includes/parser/Preprocessor_DOM.php
@@ -522,7 +522,7 @@
if ( $equalsLength > 0 ) {
if ( $searchStart - $equalsLength ==
$piece->startPos ) {
// This is just a single string
of equals signs on its own line
- // Replicate the doHeadings
behaviour /={count}(.+)={count}/
+ // Replicate the doHeadings
behavior /={count}(.+)={count}/
// First find out how many
equals signs there really are (don't stop at 6)
$count = $equalsLength;
if ( $count < 3 ) {
diff --git a/includes/parser/Preprocessor_Hash.php
b/includes/parser/Preprocessor_Hash.php
index c22da64..fe00e7f 100644
--- a/includes/parser/Preprocessor_Hash.php
+++ b/includes/parser/Preprocessor_Hash.php
@@ -462,7 +462,7 @@
if ( $equalsLength > 0 ) {
if ( $searchStart - $equalsLength ==
$piece->startPos ) {
// This is just a single string
of equals signs on its own line
- // Replicate the doHeadings
behaviour /={count}(.+)={count}/
+ // Replicate the doHeadings
behavior /={count}(.+)={count}/
// First find out how many
equals signs there really are (don't stop at 6)
$count = $equalsLength;
if ( $count < 3 ) {
diff --git a/includes/site/MediaWikiSite.php b/includes/site/MediaWikiSite.php
index 68161b9..0de97af 100644
--- a/includes/site/MediaWikiSite.php
+++ b/includes/site/MediaWikiSite.php
@@ -304,7 +304,7 @@
* @see Site::getPageUrl
*
* This implementation returns a URL constructed using the path
returned by getLinkPath().
- * In addition to the default behaviour implemented by
Site::getPageUrl(), this
+ * In addition to the default behavior implemented by
Site::getPageUrl(), this
* method converts the $pageName to DBKey-format by replacing spaces
with underscores
* before using it in the URL.
*
diff --git a/includes/specials/SpecialFilepath.php
b/includes/specials/SpecialFilepath.php
index e086650..d0ae101 100644
--- a/includes/specials/SpecialFilepath.php
+++ b/includes/specials/SpecialFilepath.php
@@ -47,7 +47,7 @@
$file = wfFindFile( $title );
if ( $file && $file->exists() ) {
- // Default behaviour: Use the direct link to
the file.
+ // Default behavior: Use the direct link to the
file.
$url = $file->getURL();
$width = $request->getInt( 'width', -1 );
$height = $request->getInt( 'height', -1 );
diff --git a/includes/specials/SpecialSearch.php
b/includes/specials/SpecialSearch.php
index 77f0ddb..3dc90c6 100644
--- a/includes/specials/SpecialSearch.php
+++ b/includes/specials/SpecialSearch.php
@@ -261,7 +261,7 @@
if( $textMatches && $textMatches->hasSuggestion() ) {
$st = SpecialPage::getTitleFor( 'Search' );
- # mirror Go/Search behaviour of original request ..
+ # mirror Go/Search behavior of original request ..
$didYouMeanParams = array( 'search' =>
$textMatches->getSuggestionQuery() );
if( $this->fulltext != null ) {
diff --git a/languages/messages/MessagesGv.php
b/languages/messages/MessagesGv.php
index 6f0b4c5..ea62cba 100644
--- a/languages/messages/MessagesGv.php
+++ b/languages/messages/MessagesGv.php
@@ -1154,7 +1154,7 @@
** Removing content from pages
** Spamming links to external sites
** Inserting nonsense/gibberish into pages
-** Intimidating behaviour/harassment
+** Intimidating behavior/harassment
** Abusing multiple accounts
* Oyr elley
** Ennym ymmydeyryn neuchooie
diff --git a/languages/messages/MessagesQqq.php
b/languages/messages/MessagesQqq.php
index 4c61090..a3cc1cc 100644
--- a/languages/messages/MessagesQqq.php
+++ b/languages/messages/MessagesQqq.php
@@ -346,8 +346,8 @@
'listingcontinuesabbrev' => 'Shown in contiuation of each first letter group.
This message follows the first letter.
See http://test.wikipedia.org/wiki/Category:Test_ko?uselang={{SUBPAGENAME}},
for example.',
-'index-category' => 'Name of the [[mw:Help:Tracking categories|tracking
category]] where pages with the <nowiki>__INDEX__</nowiki> behaviour switch are
listed. For description of this behaviour switch see
[[mw:Help:Magic_words#Behavior_switches|MediaWiki]].',
-'noindex-category' => 'Name of the [[mw:Help:Tracking categories|tracking
category]] where pages with the <nowiki>__NOINDEX__</nowiki> behaviour switch
are listed. For description of this behaviour switch see
[[mw:Help:Magic_words#Behavior_switches|MediaWiki]].',
+'index-category' => 'Name of the [[mw:Help:Tracking categories|tracking
category]] where pages with the <nowiki>__INDEX__</nowiki> behavior switch are
listed. For description of this behavior switch see
[[mw:Help:Magic_words#Behavior_switches|MediaWiki]].',
+'noindex-category' => 'Name of the [[mw:Help:Tracking categories|tracking
category]] where pages with the <nowiki>__NOINDEX__</nowiki> behavior switch
are listed. For description of this behavior switch see
[[mw:Help:Magic_words#Behavior_switches|MediaWiki]].',
'broken-file-category' => 'Name of [[mw:Help:Tracking categories|tracking
category]] where pages that embed files that do not exist ("broken images") are
listed.',
'categoryviewer-pagedlinks' => '{{Optional}}
The pagination links in category viewer. Parameters:
diff --git a/maintenance/language/messages.inc
b/maintenance/language/messages.inc
index ebf8a02..c0b0126 100644
--- a/maintenance/language/messages.inc
+++ b/maintenance/language/messages.inc
@@ -3857,7 +3857,7 @@
$wgBlockComments = array(
'sidebar' => "The sidebar for MonoBook is generated from
this message, lines that do not
begin with * or ** are discarded, furthermore lines that do begin with ** and
-do not contain | are also discarded, but do not depend on this behaviour for
+do not contain | are also discarded, but do not depend on this behavior for
future releases. Also note that since each list value is wrapped in a unique
XHTML id it should only appear once and include characters that are legal
XHTML id names.",
diff --git a/maintenance/storage/recompressTracked.php
b/maintenance/storage/recompressTracked.php
index 5e5cc8f..030a147 100644
--- a/maintenance/storage/recompressTracked.php
+++ b/maintenance/storage/recompressTracked.php
@@ -523,7 +523,7 @@
*
* Write the new URL to the text table and set the bt_moved flag.
*
- * This is done in a single transaction to provide restartable behaviour
+ * This is done in a single transaction to provide restartable behavior
* without data loss.
*
* The transaction is kept short to reduce locking.
diff --git a/resources/mediawiki/mediawiki.util.js
b/resources/mediawiki/mediawiki.util.js
index cb7dd63..5211b0d 100644
--- a/resources/mediawiki/mediawiki.util.js
+++ b/resources/mediawiki/mediawiki.util.js
@@ -437,7 +437,7 @@
// If the jQuery selector isn't found within
the <ul>,
// or if nextnode was invalid or not passed at
all,
- // then just append it at the end of the <ul>
(this is the default behaviour)
+ // then just append it at the end of the <ul>
(this is the default behavior)
} else {
$ul.append( $item );
}
diff --git a/skins/common/commonElements.css b/skins/common/commonElements.css
index 79911fe..2fa0cba 100644
--- a/skins/common/commonElements.css
+++ b/skins/common/commonElements.css
@@ -189,7 +189,7 @@
pre, code, tt, kbd, samp, .mw-code {
/*
* Some browsers will render the monospace text too small, namely
Firefox, Chrome and Safari.
- * Specifying any valid, second value will trigger correct behaviour
without forcing a different font.
+ * Specifying any valid, second value will trigger correct behavior
without forcing a different font.
*/
font-family: monospace, Courier;
}
diff --git a/tests/RunSeleniumTests.php b/tests/RunSeleniumTests.php
index 6e212eb..b7320cb 100644
--- a/tests/RunSeleniumTests.php
+++ b/tests/RunSeleniumTests.php
@@ -37,7 +37,7 @@
# PHPUnit 3.5.0 introduced a nice autoloader based on class name
require_once( 'PHPUnit/Autoload.php' );
} else {
- # Keep the old pre PHPUnit 3.5.0 behaviour for compatibility
+ # Keep the old pre PHPUnit 3.5.0 behavior for compatibility
require_once( 'PHPUnit/TextUI/Command.php' );
}
diff --git a/tests/parser/parserTests.txt b/tests/parser/parserTests.txt
index 492edb6..cb1cb84 100644
--- a/tests/parser/parserTests.txt
+++ b/tests/parser/parserTests.txt
@@ -7752,7 +7752,7 @@
!!end
!! test
-Short headings with trailing space should match behaviour of
Parser::doHeadings (bug 19910)
+Short headings with trailing space should match behavior of Parser::doHeadings
(bug 19910)
!! input
===
The line above must have a trailing space!
@@ -9863,7 +9863,7 @@
==marked==
!!end
-# Test behaviour of bug 19910
+# Test behavior of bug 19910
!! test
Sectiion with all-equals
!! options
diff --git a/tests/phpunit/maintenance/MaintenanceTest.php
b/tests/phpunit/maintenance/MaintenanceTest.php
index 235e9ad..741f8b7 100644
--- a/tests/phpunit/maintenance/MaintenanceTest.php
+++ b/tests/phpunit/maintenance/MaintenanceTest.php
@@ -92,7 +92,7 @@
// Someone generated a MaintenanceFixup instance
without calling
// simulateShutdown. We'd have to raise a PHPUnit
exception to correctly
// flag this illegal usage. However, we are already in
a destruktor, which
- // would trigger undefined behaviour. Hence, we can
only report to the
+ // would trigger undefined behavior. Hence, we can only
report to the
// error output :( Hopefully people read the PHPUnit
output.
$name = $this->testCase->getName();
fwrite( STDERR, "ERROR! Instance of " . __CLASS__ . "
for test $name "
@@ -184,7 +184,7 @@
// Although the following tests do not seem to be too consistent
(compare for
// example the newlines within the test.*StringString tests, or the
// test.*Intermittent.* tests), the objective of these tests is not to
describe
- // consistent behaviour, but rather currently existing behaviour.
+ // consistent behavior, but rather currently existing behavior.
function testOutputEmpty() {
diff --git a/tests/qunit/suites/resources/jquery/jquery.colorUtil.test.js
b/tests/qunit/suites/resources/jquery/jquery.colorUtil.test.js
index 97e0533..39ae363 100644
--- a/tests/qunit/suites/resources/jquery/jquery.colorUtil.test.js
+++ b/tests/qunit/suites/resources/jquery/jquery.colorUtil.test.js
@@ -17,7 +17,7 @@
assert.deepEqual( $.colorUtil.getRGB( '#eEe' ), [238, 238,
238], 'Hex string: 3 char mixed' );
assert.deepEqual( $.colorUtil.getRGB( 'rgba(0, 0, 0, 0)' ),
[255, 255, 255], 'Zero rgba for Safari 3; Transparent (whitespace)' );
- // Perhaps this is a bug in colorUtil, but it is the current
behaviour so, let's keep
+ // Perhaps this is a bug in colorUtil, but it is the current
behavior so, let's keep
// track of it, so we will know in case it would ever change.
assert.strictEqual( $.colorUtil.getRGB( 'rgba(0,0,0,0)' ),
undefined, 'Zero rgba without whitespace' );
diff --git a/tests/qunit/suites/resources/jquery/jquery.mwExtension.test.js
b/tests/qunit/suites/resources/jquery/jquery.mwExtension.test.js
index 5fae065..7571b92 100644
--- a/tests/qunit/suites/resources/jquery/jquery.mwExtension.test.js
+++ b/tests/qunit/suites/resources/jquery/jquery.mwExtension.test.js
@@ -40,7 +40,7 @@
assert.strictEqual( $.isEmpty( [] ), true, 'isEmpty: []' );
assert.strictEqual( $.isEmpty( {} ), true, 'isEmpty: {}' );
- // Documented behaviour
+ // Documented behavior
assert.strictEqual( $.isEmpty( { length: 0 } ), true, 'isEmpty:
{ length: 0 }' );
} );
diff --git a/languages/messages/MessagesEn.php
b/languages/messages/MessagesEn.php
index 9ea15cd..6883d8a 100644
--- a/languages/messages/MessagesEn.php
+++ b/languages/messages/MessagesEn.php
@@ -13,7 +13,7 @@
*/
/**
* Fallback language, used for all unspecified messages and behaviour. This
* is English by default, for all files other than this one.
*
* Do NOT set this to false in any other message file! Leave the line out to
@@ -620,7 +620,7 @@
/*
The sidebar for MonoBook is generated from this message, lines that do not
begin with * or ** are discarded, furthermore lines that do begin with ** and
-do not contain | are also discarded, but do not depend on this behaviour for
+do not contain | are also discarded, but do not depend on this behavior for
future releases. Also note that since each list value is wrapped in a unique
XHTML id it should only appear once and include characters that are legal
XHTML id names.
@@ -3198,7 +3198,7 @@
** Removing content from pages
** Spamming links to external sites
** Inserting nonsense/gibberish into pages
-** Intimidating behaviour/harassment
+** Intimidating behavior/harassment
** Abusing multiple accounts
** Unacceptable username',
'ipb-hardblock' => 'Prevent logged-in users from editing
@@ -13,7 +13,7 @@
*/
/**
- * Fallback language, used for all unspecified messages and behaviour. This
+ * Fallback language, used for all unspecified messages and behavior. This
* is English by default, for all files other than this one.
*
from this IP address',
--
To view, visit https://gerrit.wikimedia.org/r/51994
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings
Gerrit-MessageType: newchange
Gerrit-Change-Id: I576ed4bc0abe5ab980aaee3fb9f9e4b43087311f
Gerrit-PatchSet: 1
Gerrit-Project: mediawiki/core
Gerrit-Branch: master
Gerrit-Owner: Siebrand <[email protected]>
_______________________________________________
MediaWiki-commits mailing list
[email protected]
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits